.. _users-guide-index:

############
User's guide
############

.. only:: html

    :Release: |version|
    :Date: |today|

.. toctree::
    :maxdepth: 2

    interactive.rst
    fonts.rst
    release_notes.rst
    license.rst
    ../citing.rst
    ../resources/index.rst
    ../faq/index.rst
    credits.rst
    history.rst
